@@ -7,11 +7,11 @@ written in Python, for human beings.
 """
 
 # fmt: off
-from .api import (community, events, forsale, gigs,
-                  housing, jobs, services, resumes)
+from pycraigslist.api import (community, events, forsale, gigs,
+                              housing, jobs, services, resumes)
 
 __all__ = ["community", "events", "forsale", "gigs",
            "housing", "jobs", "services", "resumes"]
 # fmt: on
 
-__version__ = "0.4.4"
+__version__ = "0.4.5"
